@@ -1,6 +1,6 @@
 package Workflow::Factory;
 
-# $Id: Factory.pm 590 2012-11-11 14:48:28Z jonasbn $
+# $Id: Factory.pm 516 2010-01-30 13:41:38Z jonasbn $
 
 use warnings;
 use strict;
@@ -10,7 +10,8 @@ use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( configuration_error workflow_error );
 use Carp qw(croak);
 use English qw( -no_match_vars );
-$Workflow::Factory::VERSION = '1.22';
+
+$Workflow::Factory::VERSION = '1.19';
 
 my ($log);
 my (%INSTANCES);
@@ -254,8 +255,8 @@ sub _add_workflow_config {
 
             # Add the workflow type to the state conf.
             $state_conf->{type} = $wf_type;
-            my $wf_state = Workflow::State->new( $state_conf, $self );
 
+            my $wf_state = Workflow::State->new($state_conf);
             push @{ $self->{_workflow_state}{$wf_type} }, $wf_state;
         }
 
@@ -325,21 +326,19 @@ sub _load_class {
 }
 
 sub create_workflow {
-    my ( $self, $wf_type, $context, $wf_class ) = @_;
+    my ( $self, $wf_type ) = @_;
     $log ||= get_logger();
 
-    $wf_class = 'Workflow' unless ($wf_class);
-
     my $wf_config = $self->_get_workflow_config($wf_type);
     unless ($wf_config) {
         workflow_error "No workflow of type '$wf_type' available";
     }
 
     my $wf
-        = $wf_class->new( undef,
+        = Workflow->new( undef,
         $wf_config->{initial_state} || $DEFAULT_INITIAL_STATE,
-        $wf_config, $self->{_workflow_state}{$wf_type}, $self );
-    $wf->context( $context || Workflow::Context->new );
+        $wf_config, $self->{_workflow_state}{$wf_type} );
+    $wf->context( Workflow::Context->new );
     $wf->last_update( DateTime->now( time_zone => $wf->time_zone() ) );
     $log->is_info
         && $log->info("Instantiated workflow object properly, persisting...");
@@ -366,13 +365,6 @@ sub create_workflow {
 
     $self->_commit_transaction($wf);
 
-    my $state = $wf->_get_workflow_state();
-    if ( $state->autorun ) {
-        $log->is_info && $log->info( "State '$state' marked to be run ",
-            "automatically; executing that state/action..." );
-        $wf->_auto_execute_state($state);
-    }
-
     $self->associate_observers_with_workflow($wf);
     $wf->notify_observers('create');
 
@@ -380,11 +372,9 @@ sub create_workflow {
 }
 
 sub fetch_workflow {
-    my ( $self, $wf_type, $wf_id, $context, $wf_class ) = @_;
+    my ( $self, $wf_type, $wf_id ) = @_;
     $log ||= get_logger();
 
-    $wf_class = 'Workflow' unless ($wf_class);
-
     my $wf_config = $self->_get_workflow_config($wf_type);
     unless ($wf_config) {
         workflow_error "No workflow of type '$wf_type' available";
@@ -400,9 +390,8 @@ sub fetch_workflow {
         "[Last update: $wf_info->{last_update}]"
         );
     my $wf = Workflow->new( $wf_id, $wf_info->{state}, $wf_config,
-        $self->{_workflow_state}{$wf_type}, $self );
-
-    $wf->context( $wf_info->{context} || Workflow::Context->new ); #if ( not $wf->context() );
+        $self->{_workflow_state}{$wf_type} );
+    $wf->context( Workflow::Context->new ) if ( not $wf->context() );
     $wf->last_update( $wf_info->{last_update} );
 
     $persister->fetch_extra_workflow_data($wf);
@@ -853,19 +842,12 @@ The factory is a singleton, this is how you get access to the
 instance. You can also just import the 'FACTORY' constant as in the
 L</SYNOPSIS>.
 
-=head3 create_workflow( $workflow_type, $context, $wf_class )
+=head3 create_workflow( $workflow_type )
 
 Create a new workflow of type C<$workflow_type>. This will create a
 new record in whatever persistence mechanism you have associated with
 C<$workflow_type> and set the workflow to its initial state.
 
-The C<$context> argument is optional, you can pass an exisiting instance 
-of Workflow::Context to be reused. Otherwise a new instance is created.
-
-The C<$wf_class> argument is optional. Pass it the name of a class to be
-used for the workflow to be created. By default, all workflows are of the 
-I<Workflow> class.
-
 Any observers you've associated with this workflow type will be
 attached to the returned workflow object.
 
@@ -874,20 +856,13 @@ C<WORKFLOWS ARE OBSERVABLE> in L<Workflow> for more.
 
 Returns: newly created workflow object.
 
-=head3 fetch_workflow( $workflow_type, $workflow_id, $context, $wf_class )
+=head3 fetch_workflow( $workflow_type, $workflow_id )
 
 Retrieve a workflow object of type C<$workflow_type> and ID
 C<$workflow_id>. (The C<$workflow_type> is necessary so we can fetch
 the workflow using the correct persister.) If a workflow with ID
 C<$workflow_id> is not found C<undef> is returned.
 
-The C<$context> argument is optional, you can pass an exisiting instance 
-of Workflow::Context to be reused. Otherwise a new instance is created.
-
-The C<$wf_class> argument is optional. Pass it the name of a class to be
-used for the workflow to be created. By default, all workflows are of the 
-I<Workflow> class.
-
 Any observers you've associated with this workflow type will be
 attached to the returned workflow object.
 
@@ -1189,7 +1164,7 @@ L<Workflow::Validator>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2010 Chris Winters. All rights reserved.
+Copyright (c) 2003-2007 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -1198,6 +1173,6 @@ it under the same terms as Perl itself.
 
 Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
 
-Chris Winters E <lt> chris @cwinters . comE <gt>, original author .
+Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
 
 =cut
