@@ -1,6 +1,6 @@
 package Workflow::State;
 
-# $Id: State.pm 454 2009-01-12 10:04:02Z jonasbn $
+# $Id: State.pm 516 2010-01-30 13:41:38Z jonasbn $
 
 use warnings;
 use strict;
@@ -11,7 +11,7 @@ use Workflow::Exception qw( workflow_error );
 use Workflow::Factory qw( FACTORY );
 use English qw( -no_match_vars );
 
-$Workflow::State::VERSION = '1.14';
+$Workflow::State::VERSION = '1.15';
 
 my @FIELDS   = qw( state description type );
 my @INTERNAL = qw( _test_condition_count );
@@ -48,7 +48,14 @@ sub get_available_action_names {
     $self->clear_condition_cache();
 
     foreach my $action_name (@all_actions) {
-        my $action_group = FACTORY->{_action_config}{$action_name}{'group'};
+
+        #my $action_group = FACTORY->{_action_config}{$action_name}{'group'};
+
+        #From Ivan Paponov
+        my $action_group
+            = FACTORY->{_action_config}{ $self->type() }{$action_name}
+            {'group'};
+
         if ( defined $group && length $group ) {
             if ( $action_group ne $group ) {
                 next;
@@ -406,8 +413,8 @@ sub _get_next_condition_count {
     my ($self) = @_;
 
     # Initialize if not set.
-    my $count =
-        defined $self->_test_condition_count()
+    my $count
+        = defined $self->_test_condition_count()
         ? $self->_test_condition_count() + 1
         : 1;
 
